<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class Account extends MY_Controller {

    public function __construct() {
        parent::__construct();
        $this->load->library('Pages_model');
        $this->load->helper('jsonindent');
        load_lang_d($this,'accounts');
    }

    // 'page' functions
    //

    public function logout(){
        $page = 'login';
        $data = !empty($data) ? $data : array();
        $data['allowAccess'] = true; // all access
        $this->session->set_userdata('userStatus', '');
        header("Location: {$this->wwwroot}login") ;
        exit();
    }

    public function login(){
        if (strpos($_SERVER['REQUEST_URI'], 'login') === false){
            header("Location: {$this->wwwroot}login") ;
            exit();
        }
        $page = 'login';
        $data['allowAccess'] = true; // all access
        $loginAccount = isset($_POST['account'])? $_POST['account'] : null ;
        $loginPassword = isset($_POST['password'])? $_POST['password'] : null ;
        $loggedAccount = $this->_account_login($loginAccount,$loginPassword);
        $loginAs = ($loggedAccount == 'NEW') ? 'Admin' : $loggedAccount ;

        if ($loggedAccount) {
            $this->session->set_userdata('userStatus', $loginAs);
            //echo"LOGGED ACCOUNT $loggedAccount";die;
        }
        if ( $this->session->userdata('userStatus') ){
            header("Location: {$this->wwwroot}home");
            exit();
        }
        $this->_view_page($page, $data);
    }

    public function advanced_accounts(){
        $page = 'advanced_accounts';
        $data = !empty($data) ? $data : array();
        $data['allowAccess'] = false;
        $data['title'] = 'Accounts';
        $data['onTab'] = 'advanced';
        if ($this->session->userdata('userStatus') == 'Admin')  {
            $data['allowAccess'] = true; // Admin only access
        }
        $data['pageerrors'] = '';
        $pageInfo = $this->pages_model->pages['password_config'];
        $pageInfo->load();

        if ( isset($_POST['submit_accounts'])){
          if ($pageInfo->pagename=='password_config' && array_key_exists('AdminPassword',$pageInfo->fields)) {
            // check for admin password before update_from_post() because admin PW gets put in json if editing it
            $pwfield=$pageInfo->fields['AdminPassword'];
            if (!$pwfield->test_password($pageInfo->json,field_password::get_raw_value_from_post('AdminPassword_old'))) {
              $pageInfo->pageerrors.=lang_x('err_adminpassword');
            }
          }
          if (!$pageInfo->pageerrors) {
            $pageInfo->update_from_post();
            if ($pageInfo->validate()) {
              if ($pageInfo->save()) {
                if (count($pageInfo->fieldsupdated)>0) {
                  $fields=implode(', ',$pageInfo->fieldsupdated);
                  $pageInfo->pageerrors=lang_x('success_passwords saved').": $fields";
                } else {
                  $pageInfo->pageerrors=lang_x('err_no_passwords_saved');
                }
                $pageInfo->load(); // reload admin password for greying out "Old Password" field.
              } else {
                $pageInfo->pageerrors=lang_x('err_password_save');
              }
            } else {
              $pageInfo->pageerrors=lang_x('err_password_validation');
            }
          }
        }
        $data['config']=$pageInfo->fields['AdminPassword']->read_value($pageInfo->json)?'default':'';
        $data['pageerrors']=$pageInfo->pageerrors;
        $data['fielderrors']=$pageInfo->fielderrors;
        $this->_view_page($page,$data);
    }



    //
    // 'utility' functions
    //
    protected function _view_page($page,$data){
        $this->_view_dir_page('account',$page,$data);
    }

    protected function _account_login($subName=false,$subPass=false){
        $pageInfo = $this->pages_model->pages['password_config'];
        $pageInfo->load();
        $adminPW=$pageInfo->fields['AdminPassword']->read_value($pageInfo->json);
        $operPW=$pageInfo->fields['OperatorPassword']->read_value($pageInfo->json);
        $userPW=$pageInfo->fields['UserPassword']->read_value($pageInfo->json);
        if (!trim($adminPW) && !trim($operPW) && !trim($userPW)) {
          return 'NEW';
        } else {
          if ($subName && array_key_exists($subName.'Password',$pageInfo->fields)) {
            if ($pageInfo->fields[$subName.'Password']->test_password($pageInfo->json,$subPass)) {
              return $subName;
            }
          }
        }
        return false;
    }

}

?>