<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

/**
 * This controller is used for testing the pages data model.
 */
class Test_models extends MY_Controller {

    public function __construct() {
      parent::__construct();
      $this->load->library('Pages_model');
      $this->load->helper('jsonindent');
      load_lang_d($this,'modelPages');
      $this->load->library('Software_manager');
      if ($this->session->userdata('userStatus') != 'Admin') {
          header("Location: {$this->wwwroot}login");
          exit();
      }
    }

    public function index() {
      $this->load->view('test_models/index');
    }

    public function pages_schema() {
      $this->pages_model->schema_table();
    }

    public function value_table($pagename='port_config') {
      $page=$this->pages_model->pages[$pagename];
      $page->load();
      $data['page'] = &$page;
      $this->load->view('test_models/value_table',$data);
    }

    public function edit_table($pagename='port_config') {
      $page=$this->pages_model->pages[$pagename];
      $page->load();
      if (array_key_exists('save',$_POST)) {
        $page->pageerrors='';
        if ($page->pagename=='password_config' && array_key_exists('AdminPassword',$page->fields)) {
          // check for admin password before update_from_post() because admin PW gets put in json if editing it
          $pwfield=$page->fields['AdminPassword'];
          if (!$pwfield->test_password($page->json,$_POST['AdminPassword_old'])) {
            $page->pageerrors.=lang_d('err_adminpassword');
          }
        }
        if (!$page->pageerrors) {
          $page->update_from_post();
          if ($page->validate()) {
            if ($page->save()) {
              header("location: ../value_table/$pagename");
              exit();
            }
          }
        }
        if ($page->pageerrors) {
          echo "<div style='color:red'>".nl2br($page->pageerrors)."</div>";
        }
        if ($page->fielderrors || $page->porterrors) {
          echo "<div style='color:red'>Error(s) in values, see below.</div>";
        }
      }
      $data['page']=&$page;
      $this->load->view('test_models/edit_table',$data);
    }

    public function reset_table($pagename='port_config') {
      $page=$this->pages_model->pages[$pagename];
      $page->reset();
      header("location: ../value_table/$pagename");
      exit();
    }

    static function dump_log()
    {
      echo "<pre>";
      echo file_get_contents('assets/test_scripts/test_log.txt');
      echo "</pre>";
      file_put_contents('assets/test_scripts/test_log.txt','');
    }

    public function software()
    {
      file_put_contents('assets/test_scripts/test_log.txt','');
      echo "<h2>Application versions:</h2>\n";
      $apps=$this->software_manager->getApplicationVersions();
      if ($apps) {
        echo "<pre>";var_dump($apps);echo "</pre>";
      } else {
        echo nl2br($this->software_manager->get_errors());
      }
      self::dump_log();

      echo "<h2>Partition versions:</h2>\n";
      $partitions=$this->software_manager->getPartitionVersions();
      if ($partitions) {
        echo "<pre>";var_dump($partitions);echo "</pre>";
      } else {
        echo nl2br($this->software_manager->get_errors());
      }
      self::dump_log();

      echo "<h2>reboot and reinit</h2>\n";
      $result=$this->software_manager->reboot();
      echo "testing reboot: ".$result."<br>";
      self::dump_log();

      $result=$this->software_manager->reinitialize_port(1);
      echo "testing reinit: ".$result."<br>";
      self::dump_log();

      echo "<h2>Application files:</h2>\n";
      echo "verifying a non-existent application file: ";
      $result=$this->software_manager->verifyApplication('assets/test_scripts/gzorninplatz');
      if ($result) {
        echo "success<br/>";
      } else {
        echo $this->software_manager->get_errors()."<br/>\n";
      }
      self::dump_log();

      echo "verifying an application file: ";
      $result=$this->software_manager->verifyApplication('assets/test_scripts/test_include.php');
      if ($result) {
        echo "success<br/>";
      } else {
        echo $this->software_manager->get_errors()."<br/>\n";
      }
      self::dump_log();

      echo "installing a non-existent application file: ";
      $result=$this->software_manager->installApplication('assets/test_scripts/gzorninplatz');
      if ($result) {
        echo "success<br/>";
      } else {
        echo $this->software_manager->get_errors()."<br/>\n";
      }
      self::dump_log();

      echo "installing an application file: ";
      $result=$this->software_manager->installApplication('assets/test_scripts/test_include.php');
      if ($result) {
        echo "success<br/>";
      } else {
        echo $this->software_manager->get_errors()."<br/>\n";
      }
      self::dump_log();

      foreach ($partitions AS $partition=>$version) {
        echo "<h2>$partition</h2>\n";
        echo "verifying a non-existent $partition file: ";
        $result=$this->software_manager->verifyImageFile('assets/test_scripts/gzorninplatz',$partition);
        if ($result) {
          echo "success<br/>";
        } else {
          echo $this->software_manager->get_errors()."<br/>\n";
        }
        self::dump_log();

        echo "verifying $partition: ";
        $result=$this->software_manager->verifyImageFile('assets/test_scripts/test_include.php',$partition);
        if ($result) {
          echo "success<br/>";
        } else {
          echo $this->software_manager->get_errors()."<br/>\n";
        }
        self::dump_log();

        echo "installing a non-existent $partition file: ";
        $result=$this->software_manager->installImageFile('assets/test_scripts/gzorninplatz',$partition);
        if ($result) {
          echo "success<br/>";
        } else {
          echo $this->software_manager->get_errors()."<br/>\n";
        }
        self::dump_log();

        echo "installing $partition: ";
        $result=$this->software_manager->installImageFile('assets/test_scripts/test_include.php',$partition);
        if ($result) {
          echo "success<br/>";
        } else {
          echo $this->software_manager->get_errors()."<br/>\n";
        }
        self::dump_log();
      }
    }

    public function logs()
      {
      $logfiles=$this->software_manager->listLogFiles();
      echo "Available log files:<pre>";var_dump($logfiles);echo "</pre>";

      foreach ($logfiles AS $logfile) {
        echo "<div border=1>";
        echo "<h1>$logfile</h1>";
        $log=$this->software_manager->getLogFile($logfile);
        if ($log) {
        echo "<pre>".$this->software_manager->getLogFile($logfile)."</pre>";
        } else {
          echo "Error:".$this->software_manager->get_errors();
        }
        echo "</div>";
      }

    }

    public function home_page()
    {
      $page=$this->pages_model->pages['home_page'];
      $page->load();
      foreach ($page->fields AS $field) {
        $data[$field->name]=$field->read_value($page->json);
      }
      $this->load->view('test_models/home_page',$data);
    }

    public function support_page()
    {
      $page=$this->pages_model->pages['support_page'];
      $page->load();
      $apps=$this->software_manager->getApplicationVersions();
      $data['apps'] = $apps;
      $images=$this->software_manager->getPartitionVersions();
      $data['images'] = $images;
      foreach ($page->fields AS $field) {
        $data[$field->name]=$field->read_value($page->json);
      }
      $this->load->view('test_models/support_page',$data);
    }

}
?>